// src/renderers/MeasuringEquipmentsRenderer.js
import { DCCRealListQuantity } from '../dccQuantity.js';

export class MeasuringEquipmentsRenderer {
    constructor(measuringEquipmentsData, language) {
        this.data = measuringEquipmentsData;
        this.language = language;
    }

    render() {
        const container = document.createElement('div');
        container.innerHTML = `<h3>Measuring Equipments</h3>`;

        let equipments = this.data && this.data['dcc:measuringEquipment'];
        if (!equipments) {
            container.textContent = 'No measuring equipments data available.';
            return container;
        }
        if (!Array.isArray(equipments)) {
            equipments = [equipments];
        }

        // For each measuring equipment, create an individual collapsible section.
        equipments.forEach(equipment => {
            const details = document.createElement('details');
            // Apply styling similar to influence conditions renderer
            details.style.margin = '0';
            details.style.padding = '8px';
            details.style.border = '1px solid #ccc';
            details.style.marginBottom = '10px';
            details.open = false; // collapsed by default

            // Summary: always visible – shows equipment name, manufacturer, model and first identification.
            const summary = document.createElement('summary');
            summary.style.fontWeight = 'bold';
            // Equipment name
            const eqName = this._getText(equipment['dcc:name']);
            // Manufacturer name (if available)
            const manufacturer = equipment['dcc:manufacturer']
                ? this._getText(equipment['dcc:manufacturer']['dcc:name'])
                : '';
            // Model
            const model = equipment['dcc:model'] || '';
            // First identification (if available)
            let firstId = '';
            if (
                equipment['dcc:identifications'] &&
                equipment['dcc:identifications']['dcc:identification']
            ) {
                let idents = equipment['dcc:identifications']['dcc:identification'];
                if (!Array.isArray(idents)) {
                    idents = [idents];
                }
                const first = idents[0];
                firstId = `<small>${this._getText(first['dcc:name'])}: ${first['dcc:value']}</small>`;
            }
            summary.innerHTML = `<strong>${eqName}</strong> – ${manufacturer} – Model: ${model} – ${firstId}`;
            details.appendChild(summary);

            // Expanded content container
            const contentDiv = document.createElement('div');
            contentDiv.style.marginTop = '8px';
            contentDiv.style.fontFamily = 'sans-serif';

            // Render full identifications if available
            if (equipment['dcc:identifications']) {
                const identSection = document.createElement('div');
                identSection.innerHTML = `<h4>Identifications</h4>`;
                let idents = equipment['dcc:identifications']['dcc:identification'];
                if (!Array.isArray(idents)) {
                    idents = [idents];
                }
                idents.forEach(id => {
                    const idName = this._getText(id['dcc:name']);
                    const idValue = id['dcc:value'] || '';
                    const issuer = id['dcc:issuer'] || '';
                    identSection.innerHTML += `<p><small>${idName} (${issuer}): ${idValue}</small></p>`;
                });
                contentDiv.appendChild(identSection);
            }

            // Render measuring equipment quantities as a table (if available)
            if (
                equipment['dcc:measuringEquipmentQuantities'] &&
                equipment['dcc:measuringEquipmentQuantities']['dcc:measuringEquipmentQuantity']
            ) {
                const qtyData = equipment['dcc:measuringEquipmentQuantities']['dcc:measuringEquipmentQuantity'];
                const quantities = Array.isArray(qtyData) ? qtyData : [qtyData];
                const table = document.createElement('table');
                table.style.width = '100%';
                table.style.borderCollapse = 'collapse';

                // Table header
                const headerRow = document.createElement('tr');
                ['Quantity', 'Value'].forEach(text => {
                    const th = document.createElement('th');
                    th.textContent = text;
                    th.style.border = '1px solid #ccc';
                    th.style.padding = '4px';
                    headerRow.appendChild(th);
                });
                table.appendChild(headerRow);

                // Render each equipment quantity
                quantities.forEach(q => {
                    const row = document.createElement('tr');
                    const nameCell = document.createElement('td');
                    nameCell.style.border = '1px solid #ccc';
                    nameCell.style.padding = '4px';
                    nameCell.textContent = this._getText(q['dcc:name']);
                    row.appendChild(nameCell);
                    const valueCell = document.createElement('td');
                    valueCell.style.border = '1px solid #ccc';
                    valueCell.style.padding = '4px';
                    const qtyObj = new DCCRealListQuantity(q);
                    // Use the DSIUnit library to convert the unit string into HTML
                    valueCell.innerHTML = qtyObj.getValues().join(' ') + ' ' + qtyObj.getUnit({ oneLine: true });
                    row.appendChild(valueCell);
                    table.appendChild(row);
                });
                contentDiv.appendChild(table);
            }

            details.appendChild(contentDiv);
            container.appendChild(details);
        });

        return container;
    }

    // Helper: extract language-specific text from a node
    _getText(node) {
        if (!node) return '';
        const content = node['dcc:content'];
        if (Array.isArray(content)) {
            const match = content.find(item => item.$ && item.$.lang === this.language) || content[0];
            return match._ || match;
        }
        return content._ || content;
    }
}
